@@ -21,6 +21,7 @@ class SoundDataset(Dataset):
         folder,
         exts = ['flac', 'wav'],
         max_length = None,
+        target_sample_hz = None,
         seq_len_multiple_of = None
     ):
         super().__init__()
@@ -32,6 +33,8 @@ class SoundDataset(Dataset):
 
         self.files = files
         self.max_length = max_length
+
+        self.target_sample_hz = target_sample_hz
         self.seq_len_multiple_of = seq_len_multiple_of
 
     def __len__(self):
@@ -39,10 +42,13 @@ class SoundDataset(Dataset):
 
     def __getitem__(self, idx):
         file = self.files[idx]
-        data, samplerate = torchaudio.load(file)
+        data, sample_hz = torchaudio.load(file)
 
         data = rearrange(data, '1 ... -> ...')
 
+        if exists(self.target_sample_hz):
+            data = torchaudio.functional.resample(data, sample_hz, self.target_sample_hz)
+
         if exists(self.max_length):
             data = data[:self.max_length]
 
